import * as i0 from '@angular/core';
import { Injectable, Optional, Inject, NgModule } from '@angular/core';
import { DateAdapter, MAT_DATE_LOCALE, MAT_DATE_FORMATS } from '@angular/material/core';
import * as _rollupMoment from 'moment-hijri';
import _rollupMoment__default from 'moment-hijri';

const MOMENT_HIJRI_DATE_FORMATS = {
    parse: {
        dateInput: 'YYYY-MM-DD',
    },
    display: {
        dateInput: 'iDD iMMMM, iYYYY',
        monthYearLabel: 'iMMMM iYYYY',
        dateA11yLabel: 'iDD iMMMM, iYYYY',
        monthYearA11yLabel: 'iMMMM iYYYY',
        monthLabel: 'iMMM',
    },
};

var DateLocaleKeys;
(function (DateLocaleKeys) {
    DateLocaleKeys["AR_SA"] = "ar-sa";
    DateLocaleKeys["AR"] = "ar";
    DateLocaleKeys["EN"] = "en";
    DateLocaleKeys["EN_US"] = "en-US";
})(DateLocaleKeys || (DateLocaleKeys = {}));

const momentHijri = _rollupMoment__default || _rollupMoment;
/** Creates an array and fills it with values. */
function range(length, valueFunction) {
    const valuesArray = Array(length);
    for (let i = 0; i < length; i++) {
        valuesArray[i] = valueFunction(i);
    }
    return valuesArray;
}
class NgxAngularMaterialHijriAdapterService extends DateAdapter {
    constructor(matDateLocale) {
        super();
        this._updateMomentLocales();
        this.setLocale(matDateLocale || '');
    }
    setLocale(locale) {
        super.setLocale(locale);
        const momentLocaleData = momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.localeData(locale);
        this._localeData = {
            firstDayOfWeek: locale === DateLocaleKeys.AR_SA
                ? momentLocaleData === null || momentLocaleData === void 0 ? void 0 : momentLocaleData.firstDayOfWeek()
                : 6,
            longMonths: momentLocaleData === null || momentLocaleData === void 0 ? void 0 : momentLocaleData.months().slice(0),
            shortMonths: momentLocaleData === null || momentLocaleData === void 0 ? void 0 : momentLocaleData.monthsShort().slice(0),
            dates: range(30, (i) => this.createDate(1443, 2, i + 1).format('iD')),
            longDaysOfWeek: momentLocaleData === null || momentLocaleData === void 0 ? void 0 : momentLocaleData.weekdays().slice(0),
            shortDaysOfWeek: momentLocaleData === null || momentLocaleData === void 0 ? void 0 : momentLocaleData.weekdaysShort().slice(0),
            narrowDaysOfWeek: momentLocaleData === null || momentLocaleData === void 0 ? void 0 : momentLocaleData.weekdaysMin().slice(0),
        };
    }
    getYear(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.iYear();
    }
    getMonth(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.iMonth();
    }
    getDate(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.iDate();
    }
    getDayOfWeek(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.day();
    }
    getMonthNames(style) {
        var _a, _b;
        return style === 'long'
            ? (_a = this._localeData) === null || _a === void 0 ? void 0 : _a.longMonths
            : (_b = this._localeData) === null || _b === void 0 ? void 0 : _b.shortMonths;
    }
    getDateNames() {
        var _a;
        return (_a = this._localeData) === null || _a === void 0 ? void 0 : _a.dates;
    }
    getDayOfWeekNames(style) {
        var _a, _b, _c;
        switch (style) {
            case 'long':
                return (_a = this._localeData) === null || _a === void 0 ? void 0 : _a.longDaysOfWeek;
            case 'short':
                return (_b = this._localeData) === null || _b === void 0 ? void 0 : _b.shortDaysOfWeek;
            case 'narrow':
                return (_c = this._localeData) === null || _c === void 0 ? void 0 : _c.narrowDaysOfWeek;
        }
    }
    getYearName(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.format('iYYYY');
    }
    getFirstDayOfWeek() {
        var _a;
        return (_a = this._localeData) === null || _a === void 0 ? void 0 : _a.firstDayOfWeek;
    }
    getNumDaysInMonth(date) {
        return momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.iDaysInMonth(this.getYear(date), this.getMonth(date)); // get the current month days number of current hijri (year and month).
    }
    clone(date) {
        return date === null || date === void 0 ? void 0 : date.clone().locale(this.locale);
    }
    createDate(year, month, date) {
        var _a;
        if (month < 0 || month > 11) {
            throw Error(`Invalid month index "${month}". Month index has to be between 0 and 11.`);
        }
        if (date < 1) {
            throw Error(`Invalid date "${date}". Date has to be greater than 0.`);
        }
        const result = (_a = this._createMoment()) === null || _a === void 0 ? void 0 : _a.iYear(year).iMonth(month).iDate(date).hours(0).minutes(0).seconds(0).milliseconds(0).locale(this.locale);
        if (this.getMonth(result) !== month) {
            throw Error(`Invalid date ${date} for month with index ${month}.`);
        }
        if (!result.isValid()) {
            throw Error(`Invalid date "${date}" for month with index "${month}".`);
        }
        return result;
    }
    today() {
        var _a;
        return (_a = this._createMoment()) === null || _a === void 0 ? void 0 : _a.locale(this.locale);
    }
    parse(value, parseFormat) {
        var _a;
        if (value && typeof value === 'string') {
            return this._createMoment(value, parseFormat, this.locale);
        }
        return value ? (_a = this._createMoment(value)) === null || _a === void 0 ? void 0 : _a.locale(this.locale) : null;
    }
    format(date, displayFormat) {
        date = this.clone(date);
        if (!this.isValid(date)) {
            throw Error('MomentHijriDateAdapter: Cannot format invalid date.');
        }
        return date === null || date === void 0 ? void 0 : date.format(displayFormat);
    }
    addCalendarYears(date, years) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.add(years, 'iYear');
    }
    addCalendarMonths(date, months) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.add(months, 'iMonth');
    }
    addCalendarDays(date, days) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.add(days, 'days');
    }
    toIso8601(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.toISOString(true);
    }
    deserialize(value) {
        var _a, _b, _c;
        let date;
        if (value instanceof Date) {
            date = (_a = this._createMoment(value)) === null || _a === void 0 ? void 0 : _a.locale(this.locale);
        }
        else if (this.isDateInstance(value)) {
            return this.clone(value);
        }
        if (typeof value === 'string') {
            if (!value) {
                return null;
            }
            date = (_b = this._createMoment(value)) === null || _b === void 0 ? void 0 : _b.locale(this.locale);
        }
        if (date && this.isValid(date)) {
            return (_c = this._createMoment(date)) === null || _c === void 0 ? void 0 : _c.locale(this.locale);
        }
        return super.deserialize(value);
    }
    isDateInstance(obj) {
        return momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.isMoment(obj);
    }
    isValid(date) {
        var _a;
        return (_a = this.clone(date)) === null || _a === void 0 ? void 0 : _a.isValid();
    }
    invalid() {
        return momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.invalid();
    }
    _createMoment(date, format, locale) {
        return momentHijri(date, format, locale);
    }
    _updateMomentLocales() {
        const iMonthNamesEn = {
            iMonths: `Muharram_Safar_Rabi' al-Awwal_Rabi' al-Thani_Jumada al-Ula_Jumada al-Alkhirah_Rajab_Sha’ban_Ramadhan_Shawwal_Thul-Qi’dah_Thul-Hijjah`.split('_'),
            iMonthsShort: `Muh_Saf_Rab-I_Rab-II_Jum-I_Jum-II_Raj_Sha_Ram_Shw_Dhu-Q_Dhu-H`.split('_'),
            months: `Muharram_Safar_Rabi' al-Awwal_Rabi' al-Thani_Jumada al-Ula_Jumada al-Alkhirah_Rajab_Sha’ban_Ramadhan_Shawwal_Thul-Qi’dah_Thul-Hijjah`.split('_'),
            monthsShort: `Muh_Saf_Rab-I_Rab-II_Jum-I_Jum-II_Raj_Sha_Ram_Shw_Dhu-Q_Dhu-H`.split('_'),
        };
        const iMonthNamesAr = {
            iMonths: 'محرم_صفر_ربيع الأول_ربيع الثاني_جمادى الأولى_جمادى الآخرة_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
            iMonthsShort: 'محرم_صفر_ربيع ١_ربيع ٢_جمادى ١_جمادى ٢_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
            months: 'محرم_صفر_ربيع الأول_ربيع الثاني_جمادى الأولى_جمادى الآخرة_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
            monthsShort: 'محرم_صفر_ربيع ١_ربيع ٢_جمادى ١_جمادى ٢_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
        };
        // Default to the momentjs 2.12+ API
        if (typeof (momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.updateLocale) === 'function') {
            // Note: We used 'ar-sa' here to override the initial moment hijri locale...
            momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.updateLocale(DateLocaleKeys.AR_SA, Object.assign({}, iMonthNamesAr));
            // Note: Don't use 'en' to prevent override the initial Date Adapter...
            momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.updateLocale(DateLocaleKeys.EN_US, Object.assign({}, iMonthNamesEn));
        }
        else {
            const oldLocale = momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.locale();
            momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.defineLocale(DateLocaleKeys.AR_SA, iMonthNamesEn);
            momentHijri === null || momentHijri === void 0 ? void 0 : momentHijri.locale(oldLocale);
        }
    }
}
NgxAngularMaterialHijriAdapterService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterService, deps: [{ token: MAT_DATE_LOCALE, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
NgxAngularMaterialHijriAdapterService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterService, decorators: [{
            type: Injectable
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [MAT_DATE_LOCALE]
                    }] }];
    } });

class MomentHijriDateModule {
}
MomentHijriDateModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MomentHijriDateModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule });
MomentHijriDateModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule, providers: [
        {
            provide: DateAdapter,
            useClass: NgxAngularMaterialHijriAdapterService,
            deps: [MAT_DATE_LOCALE],
        },
    ] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule, decorators: [{
            type: NgModule,
            args: [{
                    providers: [
                        {
                            provide: DateAdapter,
                            useClass: NgxAngularMaterialHijriAdapterService,
                            deps: [MAT_DATE_LOCALE],
                        },
                    ],
                }]
        }] });

class NgxAngularMaterialHijriAdapterModule {
}
NgxAngularMaterialHijriAdapterModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxAngularMaterialHijriAdapterModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, imports: [MomentHijriDateModule] });
NgxAngularMaterialHijriAdapterModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, providers: [
        { provide: MAT_DATE_FORMATS, useValue: MOMENT_HIJRI_DATE_FORMATS },
    ], imports: [MomentHijriDateModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [MomentHijriDateModule],
                    providers: [
                        { provide: MAT_DATE_FORMATS, useValue: MOMENT_HIJRI_DATE_FORMATS },
                    ],
                }]
        }] });

/*
 * Public API Surface of ngx-angular-material-hijri-adapter
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DateLocaleKeys, MOMENT_HIJRI_DATE_FORMATS, NgxAngularMaterialHijriAdapterModule, NgxAngularMaterialHijriAdapterService };
//# sourceMappingURL=ngx-angular-material-hijri-adapter.mjs.map
