import * as i0 from '@angular/core';
import { Injectable, Optional, Inject, NgModule } from '@angular/core';
import { DateAdapter, MAT_DATE_LOCALE, MAT_DATE_FORMATS } from '@angular/material/core';
import * as _rollupMoment from 'moment-hijri';
import _rollupMoment__default from 'moment-hijri';

const MOMENT_HIJRI_DATE_FORMATS = {
    parse: {
        dateInput: 'YYYY-MM-DD',
    },
    display: {
        dateInput: 'iDD iMMMM, iYYYY',
        monthYearLabel: 'iMMMM iYYYY',
        dateA11yLabel: 'iDD iMMMM, iYYYY',
        monthYearA11yLabel: 'iMMMM iYYYY',
        monthLabel: 'iMMM',
    },
};

var DateLocaleKeys;
(function (DateLocaleKeys) {
    DateLocaleKeys["AR_SA"] = "ar-sa";
    DateLocaleKeys["AR"] = "ar";
    DateLocaleKeys["EN"] = "en";
    DateLocaleKeys["EN_US"] = "en-US";
})(DateLocaleKeys || (DateLocaleKeys = {}));

const momentHijri = _rollupMoment__default || _rollupMoment;
/** Creates an array and fills it with values. */
function range(length, valueFunction) {
    const valuesArray = Array(length);
    for (let i = 0; i < length; i++) {
        valuesArray[i] = valueFunction(i);
    }
    return valuesArray;
}
class NgxAngularMaterialHijriAdapterService extends DateAdapter {
    constructor(matDateLocale) {
        super();
        this._updateMomentLocales();
        this.setLocale(matDateLocale || '');
    }
    setLocale(locale) {
        super.setLocale(locale);
        const momentLocaleData = momentHijri?.localeData(locale);
        this._localeData = {
            firstDayOfWeek: locale === DateLocaleKeys.AR_SA
                ? momentLocaleData?.firstDayOfWeek()
                : 6,
            longMonths: momentLocaleData?.months().slice(0),
            shortMonths: momentLocaleData?.monthsShort().slice(0),
            dates: range(30, (i) => this.createDate(1443, 2, i + 1).format('iD')),
            longDaysOfWeek: momentLocaleData?.weekdays().slice(0),
            shortDaysOfWeek: momentLocaleData?.weekdaysShort().slice(0),
            narrowDaysOfWeek: momentLocaleData?.weekdaysMin().slice(0),
        };
    }
    getYear(date) {
        return this.clone(date)?.iYear();
    }
    getMonth(date) {
        return this.clone(date)?.iMonth();
    }
    getDate(date) {
        return this.clone(date)?.iDate();
    }
    getDayOfWeek(date) {
        return this.clone(date)?.day();
    }
    getMonthNames(style) {
        return style === 'long'
            ? this._localeData?.longMonths
            : this._localeData?.shortMonths;
    }
    getDateNames() {
        return this._localeData?.dates;
    }
    getDayOfWeekNames(style) {
        switch (style) {
            case 'long':
                return this._localeData?.longDaysOfWeek;
            case 'short':
                return this._localeData?.shortDaysOfWeek;
            case 'narrow':
                return this._localeData?.narrowDaysOfWeek;
        }
    }
    getYearName(date) {
        return this.clone(date)?.format('iYYYY');
    }
    getFirstDayOfWeek() {
        return this._localeData?.firstDayOfWeek;
    }
    getNumDaysInMonth(date) {
        return momentHijri?.iDaysInMonth(this.getYear(date), this.getMonth(date)); // get the current month days number of current hijri (year and month).
    }
    clone(date) {
        return date?.clone().locale(this.locale);
    }
    createDate(year, month, date) {
        if (month < 0 || month > 11) {
            throw Error(`Invalid month index "${month}". Month index has to be between 0 and 11.`);
        }
        if (date < 1) {
            throw Error(`Invalid date "${date}". Date has to be greater than 0.`);
        }
        const result = this._createMoment()
            ?.iYear(year)
            .iMonth(month)
            .iDate(date)
            .hours(0)
            .minutes(0)
            .seconds(0)
            .milliseconds(0)
            .locale(this.locale);
        if (this.getMonth(result) !== month) {
            throw Error(`Invalid date ${date} for month with index ${month}.`);
        }
        if (!result.isValid()) {
            throw Error(`Invalid date "${date}" for month with index "${month}".`);
        }
        return result;
    }
    today() {
        return this._createMoment()?.locale(this.locale);
    }
    parse(value, parseFormat) {
        if (value && typeof value === 'string') {
            return this._createMoment(value, parseFormat, this.locale);
        }
        return value ? this._createMoment(value)?.locale(this.locale) : null;
    }
    format(date, displayFormat) {
        date = this.clone(date);
        if (!this.isValid(date)) {
            throw Error('MomentHijriDateAdapter: Cannot format invalid date.');
        }
        return date?.format(displayFormat);
    }
    addCalendarYears(date, years) {
        return this.clone(date)?.add(years, 'iYear');
    }
    addCalendarMonths(date, months) {
        return this.clone(date)?.add(months, 'iMonth');
    }
    addCalendarDays(date, days) {
        return this.clone(date)?.add(days, 'days');
    }
    toIso8601(date) {
        return this.clone(date)?.toISOString(true);
    }
    deserialize(value) {
        let date;
        if (value instanceof Date) {
            date = this._createMoment(value)?.locale(this.locale);
        }
        else if (this.isDateInstance(value)) {
            return this.clone(value);
        }
        if (typeof value === 'string') {
            if (!value) {
                return null;
            }
            date = this._createMoment(value)?.locale(this.locale);
        }
        if (date && this.isValid(date)) {
            return this._createMoment(date)?.locale(this.locale);
        }
        return super.deserialize(value);
    }
    isDateInstance(obj) {
        return momentHijri?.isMoment(obj);
    }
    isValid(date) {
        return this.clone(date)?.isValid();
    }
    invalid() {
        return momentHijri?.invalid();
    }
    _createMoment(date, format, locale) {
        return momentHijri(date, format, locale);
    }
    _updateMomentLocales() {
        const iMonthNamesEn = {
            iMonths: `Muharram_Safar_Rabi' al-Awwal_Rabi' al-Thani_Jumada al-Ula_Jumada al-Alkhirah_Rajab_Sha’ban_Ramadhan_Shawwal_Thul-Qi’dah_Thul-Hijjah`.split('_'),
            iMonthsShort: `Muh_Saf_Rab-I_Rab-II_Jum-I_Jum-II_Raj_Sha_Ram_Shw_Dhu-Q_Dhu-H`.split('_'),
            months: `Muharram_Safar_Rabi' al-Awwal_Rabi' al-Thani_Jumada al-Ula_Jumada al-Alkhirah_Rajab_Sha’ban_Ramadhan_Shawwal_Thul-Qi’dah_Thul-Hijjah`.split('_'),
            monthsShort: `Muh_Saf_Rab-I_Rab-II_Jum-I_Jum-II_Raj_Sha_Ram_Shw_Dhu-Q_Dhu-H`.split('_'),
        };
        const iMonthNamesAr = {
            iMonths: 'محرم_صفر_ربيع الأول_ربيع الثاني_جمادى الأولى_جمادى الآخرة_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
            iMonthsShort: 'محرم_صفر_ربيع ١_ربيع ٢_جمادى ١_جمادى ٢_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
            months: 'محرم_صفر_ربيع الأول_ربيع الثاني_جمادى الأولى_جمادى الآخرة_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
            monthsShort: 'محرم_صفر_ربيع ١_ربيع ٢_جمادى ١_جمادى ٢_رجب_شعبان_رمضان_شوال_ذو القعدة_ذو الحجة'.split('_'),
        };
        // Default to the momentjs 2.12+ API
        if (typeof momentHijri?.updateLocale === 'function') {
            // Note: We used 'ar-sa' here to override the initial moment hijri locale...
            momentHijri?.updateLocale(DateLocaleKeys.AR_SA, {
                ...iMonthNamesAr,
            });
            // Note: Don't use 'en' to prevent override the initial Date Adapter...
            momentHijri?.updateLocale(DateLocaleKeys.EN_US, {
                ...iMonthNamesEn,
            });
        }
        else {
            const oldLocale = momentHijri?.locale();
            momentHijri?.defineLocale(DateLocaleKeys.AR_SA, iMonthNamesEn);
            momentHijri?.locale(oldLocale);
        }
    }
}
NgxAngularMaterialHijriAdapterService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterService, deps: [{ token: MAT_DATE_LOCALE, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
NgxAngularMaterialHijriAdapterService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [MAT_DATE_LOCALE]
                }] }]; } });

class MomentHijriDateModule {
}
MomentHijriDateModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MomentHijriDateModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule });
MomentHijriDateModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule, providers: [
        {
            provide: DateAdapter,
            useClass: NgxAngularMaterialHijriAdapterService,
            deps: [MAT_DATE_LOCALE],
        },
    ] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: MomentHijriDateModule, decorators: [{
            type: NgModule,
            args: [{
                    providers: [
                        {
                            provide: DateAdapter,
                            useClass: NgxAngularMaterialHijriAdapterService,
                            deps: [MAT_DATE_LOCALE],
                        },
                    ],
                }]
        }] });

class NgxAngularMaterialHijriAdapterModule {
}
NgxAngularMaterialHijriAdapterModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxAngularMaterialHijriAdapterModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, imports: [MomentHijriDateModule] });
NgxAngularMaterialHijriAdapterModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, providers: [
        { provide: MAT_DATE_FORMATS, useValue: MOMENT_HIJRI_DATE_FORMATS },
    ], imports: [MomentHijriDateModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.1.0", ngImport: i0, type: NgxAngularMaterialHijriAdapterModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [MomentHijriDateModule],
                    providers: [
                        { provide: MAT_DATE_FORMATS, useValue: MOMENT_HIJRI_DATE_FORMATS },
                    ],
                }]
        }] });

/*
 * Public API Surface of ngx-angular-material-hijri-adapter
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DateLocaleKeys, MOMENT_HIJRI_DATE_FORMATS, NgxAngularMaterialHijriAdapterModule, NgxAngularMaterialHijriAdapterService };
//# sourceMappingURL=ngx-angular-material-hijri-adapter.mjs.map
